@@ -5,11 +5,11 @@
  * File test1.c:
  *   Test implementation of Faddeeva, Dawson, and error functions
  *   by checking against values computed using Maple and Wolfram Alfa.
- * 
+ *
  * Copyright:
  *   (C) 2012 Massachusetts Institute of Technology
  *   (C) 2013 Forschungszentrum Jülich GmbH
- * 
+ *
  * Licence:
  *   Permission is hereby granted, free of charge, to any person obtaining
  *   a copy of this software and associated documentation files (the
@@ -18,17 +18,17 @@
  *   distribute, sublicense, and/or sell copies of the Software, and to
  *   permit persons to whom the Software is furnished to do so, subject to
  *   the following conditions:
- * 
+ *
  *   The above copyright notice and this permission notice shall be
  *   included in all copies or substantial portions of the Software.
- * 
+ *
  *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
  *   NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
  *   LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
  *   OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
- *   WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
+ *   WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  *
  * Authors:
  *   Steven G. Johnson, Massachusetts Institute of Technology, 2012, core author
@@ -46,15 +46,12 @@
 
 #include "cerf.h"
 
-#define _GNU_SOURCE // enable GNU libc NAN extension if possible
-
 #include <float.h>
 #include <math.h>
-
-#include "defs.h" // defines cmplx, CMPLX, NaN
-
 #include <stdio.h>
 
+#include "defs.h" // defines _cerf_cmplx, CMPLX, NaN
+
 /******************************************************************************/
 /*  Auxiliary routines                                                        */
 /******************************************************************************/
@@ -76,48 +73,48 @@ static double relerr(double a, double b) {
 
 // For testing the complex and real Dawson and error functions.
 
-double TST( char* Fname, cmplx (*F)(cmplx), double (*FRE)(double), double isc,
-         int nTst, cmplx *w, cmplx *z )
+double TST(const char* Fname, _cerf_cmplx (*F)(_cerf_cmplx), double (*FRE)(double), double isc,
+         int nTst, _cerf_cmplx *w, _cerf_cmplx *z )
 {
     printf("############# %s(z) tests #############\n", Fname);
-    double errmax = 0;                                         
-    for (int i = 0; i < nTst; ++i) {                           
-        cmplx fw = F(z[i]);                                    
-        double re_err = relerr(creal(w[i]), creal(fw));        
-        double im_err = relerr(cimag(w[i]), cimag(fw));        
+    double errmax = 0;
+    for (int i = 0; i < nTst; ++i) {
+        _cerf_cmplx fw = F(z[i]);
+        double re_err = relerr(creal(w[i]), creal(fw));
+        double im_err = relerr(cimag(w[i]), cimag(fw));
         printf("%s(%g%+gi) = %g%+gi (vs. %g%+gi), "
                "re/im rel. err. = %0.2g/%0.2g)\n", Fname,
                creal(z[i]), cimag(z[i]), creal(fw), cimag(fw),
-               creal(w[i]), cimag(w[i]), 
-               re_err, im_err);                                        
-        if (re_err > errmax) errmax = re_err;                          
-        if (im_err > errmax) errmax = im_err;                          
-    }                                                                  
-    if (errmax > 1e-13) {                                              
-        printf("FAILURE -- relative error %g too large!\n", errmax);   
-        return errmax;                                                      
-    }                                                                  
-    printf("Checking %s(x) special case...\n", Fname);                 
-    for (int i = 0; i < 10000; ++i) {                                  
-        double x = pow(10., -300. + i * 600. / (10000 - 1));           
-        double re_err = relerr(FRE(x), creal(F(C(x,x*isc))));          
-        if (re_err > errmax) errmax = re_err;                          
-        re_err = relerr(FRE(-x), creal(F(C(-x,x*isc))));               
-        if (re_err > errmax) errmax = re_err;                          
-    }                                                                  
-    {                                                                  
-        double re_err = relerr(FRE(Inf), creal(F(C(Inf,0.))));         
-        if (re_err > errmax) errmax = re_err;                          
-        re_err = relerr(FRE(-Inf), creal(F(C(-Inf,0.))));              
-        if (re_err > errmax) errmax = re_err;                          
-        re_err = relerr(FRE(NaN), creal(F(C(NaN,0.))));                
-        if (re_err > errmax) errmax = re_err;                          
-    }                                                                  
-    if (errmax > 1e-13) {                                              
-        printf("FAILURE -- relative error %g too large!\n", errmax);   
-        return errmax;                                                      
-    }                                                                  
-    printf("SUCCESS (max relative error = %g)\n", errmax);             
+               creal(w[i]), cimag(w[i]),
+               re_err, im_err);
+        if (re_err > errmax) errmax = re_err;
+        if (im_err > errmax) errmax = im_err;
+    }
+    if (errmax > 1e-13) {
+        printf("FAILURE -- relative error %g too large!\n", errmax);
+        return errmax;
+    }
+    printf("Checking %s(x) special case...\n", Fname);
+    for (int i = 0; i < 10000; ++i) {
+        double x = pow(10., -300. + i * 600. / (10000 - 1));
+        double re_err = relerr(FRE(x), creal(F(C(x,x*isc))));
+        if (re_err > errmax) errmax = re_err;
+        re_err = relerr(FRE(-x), creal(F(C(-x,x*isc))));
+        if (re_err > errmax) errmax = re_err;
+    }
+    {
+        double re_err = relerr(FRE(Inf), creal(F(C(Inf,0.))));
+        if (re_err > errmax) errmax = re_err;
+        re_err = relerr(FRE(-Inf), creal(F(C(-Inf,0.))));
+        if (re_err > errmax) errmax = re_err;
+        re_err = relerr(FRE(NaN), creal(F(C(NaN,0.))));
+        if (re_err > errmax) errmax = re_err;
+    }
+    if (errmax > 1e-13) {
+        printf("FAILURE -- relative error %g too large!\n", errmax);
+        return errmax;
+    }
+    printf("SUCCESS (max relative error = %g)\n", errmax);
     return errmax;
 }
 
@@ -130,7 +127,7 @@ double test_w_of_z()
 {
     printf("############# w(z) tests #############\n");
 #define NTST 57
-    cmplx z[NTST] = {
+    _cerf_cmplx z[NTST] = {
         C(624.2,-0.26123),
         C(-0.4,3.),
         C(0.6,2.),
@@ -189,7 +186,7 @@ double test_w_of_z()
         C(NaN,Inf),
         C(Inf,NaN)
     };
-    cmplx w[NTST] = { /* w(z), computed with WolframAlpha
+    _cerf_cmplx w[NTST] = { /* w(z), computed with WolframAlpha
                          ... note that WolframAlpha is problematic
                          some of the above inputs, so I had to
                          use the continued-fraction expansion
@@ -301,7 +298,7 @@ double test_w_of_z()
     };
     double errmax = 0;
     for (int i = 0; i < NTST; ++i) {
-        cmplx fw = w_of_z(z[i]);
+        _cerf_cmplx fw = w_of_z(z[i]);
         double re_err = relerr(creal(w[i]), creal(fw));
         double im_err = relerr(cimag(w[i]), cimag(fw));
         printf("w(%g%+gi) = %g%+gi (vs. %g%+gi), re/im rel. err. = %0.2g/%0.2g)\n",
@@ -323,7 +320,7 @@ double test_erf()
 {
 #undef NTST
 #define NTST 41
-    cmplx z[NTST] = {
+    _cerf_cmplx z[NTST] = {
         C(1,2),
         C(-1,2),
         C(1,-2),
@@ -366,7 +363,7 @@ double test_erf()
         C(7e-2,0.9e-2),
         C(7e-2,1.1e-2)
     };
-    cmplx w[NTST] = { // erf(z[i]), evaluated with Maple
+    _cerf_cmplx w[NTST] = { // erf(z[i]), evaluated with Maple
         C(-0.5366435657785650339917955593141927494421,
           -5.049143703447034669543036958614140565553),
         C(0.5366435657785650339917955593141927494421,
@@ -446,8 +443,8 @@ double test_erfi()
     // be sufficient to make sure I didn't screw up the signs or something
 #undef NTST
 #define NTST 1 // define instead of const for C compatibility
-    cmplx z[NTST] = { C(1.234,0.5678) };
-    cmplx w[NTST] = { // erfi(z[i]), computed with Maple
+    _cerf_cmplx z[NTST] = { C(1.234,0.5678) };
+    _cerf_cmplx w[NTST] = { // erfi(z[i]), computed with Maple
         C(1.081032284405373149432716643834106923212,
           1.926775520840916645838949402886591180834)
     };
@@ -461,8 +458,8 @@ double test_erfcx()
     // be sufficient to make sure I didn't screw up the signs or something
 #undef NTST
 #define NTST 1 // define instead of const for C compatibility
-    cmplx z[NTST] = { C(1.234,0.5678) };
-    cmplx w[NTST] = { // erfcx(z[i]), computed with Maple
+    _cerf_cmplx z[NTST] = { C(1.234,0.5678) };
+    _cerf_cmplx w[NTST] = { // erfcx(z[i]), computed with Maple
         C(0.3382187479799972294747793561190487832579,
           -0.1116077470811648467464927471872945833154)
     };
@@ -474,7 +471,7 @@ double test_erfc()
 {
 #undef NTST
 #define NTST 30
-    cmplx z[NTST] = {
+    _cerf_cmplx z[NTST] = {
         C(1,2),
         C(-1,2),
         C(1,-2),
@@ -506,7 +503,7 @@ double test_erfc()
         C(Inf,NaN),
         C(88,0)
     };
-    cmplx w[NTST] = { // erfc(z[i]), evaluated with Maple
+    _cerf_cmplx w[NTST] = { // erfc(z[i]), evaluated with Maple
         C(1.536643565778565033991795559314192749442,
           5.049143703447034669543036958614140565553),
         C(0.4633564342214349660082044406858072505579,
@@ -560,7 +557,7 @@ double test_dawson()
 {
 #undef NTST
 #define NTST 48
-    cmplx z[NTST] = {
+    _cerf_cmplx z[NTST] = {
         C(2,1),
         C(-2,1),
         C(2,-1),
@@ -610,7 +607,7 @@ double test_dawson()
         C(1e13, 2.4e-16),
         C(1e300, 2.4e-303)
     };
-    cmplx w[NTST] = { // dawson(z[i]), evaluated with Maple
+    _cerf_cmplx w[NTST] = { // dawson(z[i]), evaluated with Maple
         C(0.1635394094345355614904345232875688576839,
           -0.1531245755371229803585918112683241066853),
         C(-0.1635394094345355614904345232875688576839,
@@ -719,5 +716,11 @@ int main(void) {
     if (errmax > errmax_all) errmax_all = errmax;
 
     printf("#####################################\n");
-    printf("OVERALL SUCCESS (max relative error = %g)\n", errmax_all);
+    if (errmax_all<1e-13) {
+        printf("OVERALL SUCCESS (max relative error = %g)\n", errmax_all);
+        return 0;
+    } else {
+        printf("OVERALL FAILURE (max relative error = %g is too large)\n", errmax_all);
+        return 1;
+    }
 }
